# --------------------------------------------------------------- Imports ---------------------------------------------------------------- #

# System
from enum import Enum

# ---------------------------------------------------------------------------------------------------------------------------------------- #



# --------------------------------------------------------- class: TimeInterval ---------------------------------------------------------- #

class TimeInterval(Enum):
    NOW     = 'hour'
    HOUR    = 'hour'
    DAY     = 'day'
    WEEK    = 'week'
    MONTH   = 'month'
    YEAR    = 'year'
    ALL     = 'all'


# ---------------------------------------------------------------------------------------------------------------------------------------- #